@@ -77,6 +77,9 @@ log_message('python_prefix_matches = %r', python_prefix_matches)
 log_message('python_version_matches = %r', python_version_matches)
 print("dafsdfasdfadsf")
 print("FAST_PYTHON_PREFIX:", os.environ.get('FAST_PYTHON_PREFIX'))
+print(sys.prefix)
+print(os.path.normpath(sys.prefix))
+sys.prefix = expected_python_prefix
 print("actual_python_prefix:", os.path.realpath(os.path.normpath(sys.prefix)))
 print("FAST_PYTHON_VERSION:", os.environ.get('FAST_PYTHON_VERSION'))
 print("actual_python_version:", actual_python_version)
