@@ -95,7 +95,8 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
                     print("b4")
                     data = self._get_data(segment, span)
                     print("b5")
-                    res = udp_sock.sendto(data, ('fluent-bit', 5140))
+                    # res = udp_sock.sendto(data, ('fluent-bit', 5140))
+                    res = udp_sock.sendto(data, ('127.0.0.1', 8111))
                     print("b6")
                     print("res:", res)
                     # logger.debug("report traces response: %s", res)
@@ -150,6 +151,22 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         for tag in tags_data:
             data[tag.key] = tag.val
 
+        import tornado.ioloop
+        import tornado.web
+
+        class MainHandler(tornado.web.RequestHandler):
+            def get(self):
+                self.write("Hello, world")
+
+        def make_app():
+            return tornado.web.Application([
+                (r"/", MainHandler),
+            ])
+
+        if __name__ == "__main__":
+            app = make_app()
+            app.listen(8888)
+            tornado.ioloop.IOLoop.current().start()
         return data
 
     def convert_logs(self, logs_data):
